==> ejc-procurement-impl-3.0.0-20251216.092729-140-sources.jar: com/ejianc/business/procurement/perform/controller/ReviewAnnounceController.java <==
package com.ejianc.business.procurement.perform.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.procurement.perform.bean.ReviewAnnounceConfirmEntity;
import com.ejianc.business.procurement.perform.bean.ReviewAnnounceSupplierEntity;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceConfirmService;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceSupplierService;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceConfirmVO;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceSupplierVO;
import com.ejianc.business.procurement.utils.TreeNodeBUtil;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.procurement.perform.bean.ReviewAnnounceEntity;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceService;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceVO;

/**
 * 采购前公示结果评审表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("reviewAnnounce")
public class ReviewAnnounceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String HW_BILL_CODE = "HW-REVIEW-CODE";
    private static final String GC_BILL_CODE = "GC-REVIEW-CODE";
    private static final String FW_BILL_CODE = "FW-REVIEW-CODE";
    @Autowired
    private IReviewAnnounceService service;
    @Autowired
    private IReviewAnnounceConfirmService reviewAnnounceConfirmService;
    @Autowired
    private IReviewAnnounceSupplierService reviewAnnounceSupplierService;
    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ReviewAnnounceVO> saveOrUpdate(@RequestBody ReviewAnnounceVO saveOrUpdateVO) {
    	ReviewAnnounceEntity entity = BeanMapper.map(saveOrUpdateVO, ReviewAnnounceEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            String billcode = "";
            if("1".equals(saveOrUpdateVO.getBusinessType())){
                billcode = GC_BILL_CODE;
            }else if("2".equals(saveOrUpdateVO.getBusinessType())){
                billcode = HW_BILL_CODE;
            }else if("3".equals(saveOrUpdateVO.getBusinessType())){
                billcode = FW_BILL_CODE;
            }
            BillCodeParam billCodeParam = BillCodeParam.build(billcode,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }


        if(entity.getId() == null || entity.getId() == 0){

        }else{
            //如果是修改的话  先根据主表id删除孙子表的所有信息
            LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
            lambda.eq(ReviewAnnounceSupplierEntity::getPid, entity.getId());
            reviewAnnounceSupplierService.remove(lambda);
        }

        List<ReviewAnnounceConfirmVO> detailListVo = saveOrUpdateVO.getReviewAnnounceConfirmList();
        Map<String,List<ReviewAnnounceSupplierVO>> sipplierMap = new HashMap<>();
        if(CollectionUtils.isNotEmpty(detailListVo)){
            detailListVo.forEach(e->{
                if(!"del".equals(e.getRowState())){
                    sipplierMap.put(e.getTid(),e.getSupplierList());
                }
            });
        }
    	service.saveOrUpdate(entity, false);
        //更新子表的 树形结构
        List<ReviewAnnounceConfirmEntity> detailList = entity.getReviewAnnounceConfirmList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            Map<String, Long> idMap = new HashMap<>();
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                idMap.put(cdEntity.getTid(), cdEntity.getId());
            }
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                if (StringUtils.isNotEmpty(cdEntity.getTpid())) {
                    cdEntity.setParentId(idMap.get(cdEntity.getTpid()));
                }
            }
            reviewAnnounceConfirmService.saveOrUpdateBatch(detailList);
        }
       //更新孙子表记录的 主表id,子表id
        if (CollectionUtils.isNotEmpty(detailList)) {
            List<ReviewAnnounceSupplierEntity> detailSupplierList = new ArrayList<>();
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                List<ReviewAnnounceSupplierEntity> supplierVOS = BeanMapper.mapList(sipplierMap.get(cdEntity.getTid()),ReviewAnnounceSupplierEntity.class);
                supplierVOS.forEach(e->{
                    e.setPid(entity.getId());
                    e.setConfirmId(cdEntity.getId());
                    e.setRowState("add");
                });
                detailSupplierList.addAll(supplierVOS);
            }
            reviewAnnounceSupplierService.saveOrUpdateBatch(detailSupplierList);
        }

    	return queryDetail(entity.getId());
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ReviewAnnounceVO> queryDetail(Long id) {
    	ReviewAnnounceEntity entity = service.selectById(id);
    	ReviewAnnounceVO vo = BeanMapper.map(entity, ReviewAnnounceVO.class);
        LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
        lambda.eq(ReviewAnnounceSupplierEntity::getPid, entity.getId());
        List<ReviewAnnounceSupplierEntity> supplierEntityList = reviewAnnounceSupplierService.list(lambda);
        Map<Long,List<ReviewAnnounceSupplierEntity>> map = supplierEntityList .stream().collect(Collectors.groupingBy(ReviewAnnounceSupplierEntity::getConfirmId));
        List<ReviewAnnounceConfirmVO> detailEntityList = vo.getReviewAnnounceConfirmList();
        if (CollectionUtils.isNotEmpty(detailEntityList)) {
            for(ReviewAnnounceConfirmVO confirmVO:detailEntityList){
                confirmVO.setSupplierList(BeanMapper.mapList(map.get(confirmVO.getId()),ReviewAnnounceSupplierVO.class));
            }
            vo.setReviewAnnounceConfirmList(TreeNodeBUtil.buildTree(detailEntityList));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ReviewAnnounceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ReviewAnnounceVO vo : vos) {
                LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
                lambda.eq(ReviewAnnounceSupplierEntity::getPid, vo.getId());
                reviewAnnounceSupplierService.remove(lambda);
            }
        }
        service.removeByIds(vos.stream().map(ReviewAnnounceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ReviewAnnounceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "name", "orgName", "executePlanCode"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ReviewAnnounceEntity> page = service.queryPage(param,false);
        IPage<ReviewAnnounceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ReviewAnnounceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "name", "orgName", "executePlanCode"));
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ReviewAnnounceEntity> list = service.queryList(param);
        List<ReviewAnnounceVO> voList = BeanMapper.mapList(list, ReviewAnnounceVO.class);
        for (ReviewAnnounceVO vo : voList) {
            Integer permissionType = vo.getPermissionType();
            if (permissionType != null) {
                if (permissionType.intValue() == 1) {
                    vo.setPermissionTypeName("一级集采");
                } else if (permissionType.intValue() == 2) {
                    vo.setPermissionTypeName("二级集采");
                } else if (permissionType.intValue() == 3) {
                    vo.setPermissionTypeName("所属单位");
                } else if (permissionType.intValue() == 4) {
                    vo.setPermissionTypeName("项目经理部");
                }
            }
            String businessType = vo.getBusinessType();
            if ("1".equals(businessType)) {
                vo.setBusinessTypeName("工程");
            } else if ("2".equals(businessType)) {
                vo.setBusinessTypeName("货物");
            }else {
                vo.setBusinessTypeName("服务");
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("ReviewAnnounce-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refReviewAnnounceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ReviewAnnounceVO>> refReviewAnnounceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewAnnounceEntity> page = service.queryPage(param,false);
        IPage<ReviewAnnounceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ReviewAnnounceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}

==> ejc-procurement-impl-3.0.0-20251217.031314-143-sources.jar: com/ejianc/business/procurement/perform/controller/ReviewAnnounceController.java <==
package com.ejianc.business.procurement.perform.controller;

import java.io.Serializable;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.procurement.perform.bean.PurchaseProjectEntity;
import com.ejianc.business.procurement.perform.bean.ReviewAnnounceConfirmEntity;
import com.ejianc.business.procurement.perform.bean.ReviewAnnounceSupplierEntity;
import com.ejianc.business.procurement.perform.service.IPurchaseProjectService;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceConfirmService;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceSupplierService;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceConfirmVO;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceSupplierVO;
import com.ejianc.business.procurement.utils.TreeNodeBUtil;
import com.ejianc.foundation.orgcenter.vo.OrgVO;
import com.ejianc.foundation.support.vo.BillCodeParam;
import com.ejianc.foundation.support.api.IBillCodeApi;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.exception.BusinessException;
import com.ejianc.framework.core.util.ExcelExport;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import java.util.*;
import java.util.stream.Collectors;
import com.alibaba.fastjson.JSONObject;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.*;
import org.apache.commons.collections.CollectionUtils;
import javax.servlet.http.HttpServletResponse;

import com.ejianc.foundation.orgcenter.api.IOrgApi;
import com.ejianc.framework.core.response.CommonResponse;
import org.springframework.beans.factory.annotation.Autowired;
import com.ejianc.framework.core.context.InvocationInfoProxy;
import com.ejianc.framework.core.kit.mapper.BeanMapper;
import com.ejianc.framework.core.kit.collection.ListUtil;
import com.ejianc.framework.auth.session.SessionManager;
import com.ejianc.framework.auth.session.UserContext;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ejianc.framework.core.response.Parameter;
import com.ejianc.framework.core.response.QueryParam;

import com.ejianc.business.procurement.perform.bean.ReviewAnnounceEntity;
import com.ejianc.business.procurement.perform.service.IReviewAnnounceService;
import com.ejianc.business.procurement.perform.vo.ReviewAnnounceVO;

/**
 * 采购前公示结果评审表
 *
 * @author generator
 *
 */
@Controller
@RequestMapping("reviewAnnounce")
public class ReviewAnnounceController implements Serializable {
	private static final long serialVersionUID = 1L;

    private Logger logger = LoggerFactory.getLogger(this.getClass());

    @Autowired
    private IBillTypeApi billTypeApi;
    @Autowired
    private IBillCodeApi billCodeApi;
    @Autowired
    private IOrgApi iOrgApi;

    private static final String HW_BILL_CODE = "HW-REVIEW-CODE";
    private static final String GC_BILL_CODE = "GC-REVIEW-CODE";
    private static final String FW_BILL_CODE = "FW-REVIEW-CODE";
    @Autowired
    private IReviewAnnounceService service;
    @Autowired
    private IReviewAnnounceConfirmService reviewAnnounceConfirmService;
    @Autowired
    private IReviewAnnounceSupplierService reviewAnnounceSupplierService;
    @Autowired
    private IPurchaseProjectService purchaseProjectService;
    @Autowired
    private SessionManager sessionManager;

    /**
     * @Description saveOrUpdate 新增或者修改
     */
    @RequestMapping(value = "/saveOrUpdate", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<ReviewAnnounceVO> saveOrUpdate(@RequestBody ReviewAnnounceVO saveOrUpdateVO) {
    	ReviewAnnounceEntity entity = BeanMapper.map(saveOrUpdateVO, ReviewAnnounceEntity.class);
    	if(entity.getId() == null || entity.getId() == 0){
            String billcode = "";
            if("1".equals(saveOrUpdateVO.getBusinessType())){
                billcode = GC_BILL_CODE;
            }else if("2".equals(saveOrUpdateVO.getBusinessType())){
                billcode = HW_BILL_CODE;
            }else if("3".equals(saveOrUpdateVO.getBusinessType())){
                billcode = FW_BILL_CODE;
            }
            BillCodeParam billCodeParam = BillCodeParam.build(billcode,InvocationInfoProxy.getTenantid(),saveOrUpdateVO);
            CommonResponse<String> billCode = billCodeApi.generateBillCode(billCodeParam);
            if(billCode.isSuccess()) {
                //entity.setCode(billCode.getData());//此处需要根据实际修改 删除本行或者下一行
                entity.setBillCode(billCode.getData());//此处需要根据实际修改 删除本行或者上一行
            }else{
                throw new BusinessException("网络异常， 编码生成失败， 请稍后再试");
            }
        }


        if(entity.getId() == null || entity.getId() == 0){

        }else{
            //如果是修改的话  先根据主表id删除孙子表的所有信息
            LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
            lambda.eq(ReviewAnnounceSupplierEntity::getPid, entity.getId());
            reviewAnnounceSupplierService.remove(lambda);
        }

        List<ReviewAnnounceConfirmVO> detailListVo = saveOrUpdateVO.getReviewAnnounceConfirmList();
        Map<String,List<ReviewAnnounceSupplierVO>> sipplierMap = new HashMap<>();
        if(CollectionUtils.isNotEmpty(detailListVo)){
            detailListVo.forEach(e->{
                if(!"del".equals(e.getRowState())){
                    sipplierMap.put(e.getTid(),e.getSupplierList());
                }
            });
        }
    	service.saveOrUpdate(entity, false);
        //更新子表的 树形结构
        List<ReviewAnnounceConfirmEntity> detailList = entity.getReviewAnnounceConfirmList();
        if (CollectionUtils.isNotEmpty(detailList)) {
            Map<String, Long> idMap = new HashMap<>();
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                idMap.put(cdEntity.getTid(), cdEntity.getId());
            }
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                if (StringUtils.isNotEmpty(cdEntity.getTpid())) {
                    cdEntity.setParentId(idMap.get(cdEntity.getTpid()));
                }
            }
            reviewAnnounceConfirmService.saveOrUpdateBatch(detailList);
        }
       //更新孙子表记录的 主表id,子表id
        if (CollectionUtils.isNotEmpty(detailList)) {
            List<ReviewAnnounceSupplierEntity> detailSupplierList = new ArrayList<>();
            for (ReviewAnnounceConfirmEntity cdEntity : detailList) {
                List<ReviewAnnounceSupplierEntity> supplierVOS = BeanMapper.mapList(sipplierMap.get(cdEntity.getTid()),ReviewAnnounceSupplierEntity.class);
                supplierVOS.forEach(e->{
                    e.setPid(entity.getId());
                    e.setConfirmId(cdEntity.getId());
                    e.setRowState("add");
                });
                detailSupplierList.addAll(supplierVOS);
            }
            reviewAnnounceSupplierService.saveOrUpdateBatch(detailSupplierList);
        }

        if (entity.getPurchaseProjectId() != null) {
            LambdaUpdateWrapper<PurchaseProjectEntity> updateWrapper = Wrappers.lambdaUpdate();
            updateWrapper.eq(PurchaseProjectEntity::getId, entity.getPurchaseProjectId());
            updateWrapper.set(PurchaseProjectEntity::getDirectFlag, 1);
            purchaseProjectService.update(updateWrapper);
        }

    	return queryDetail(entity.getId());
    }

    /**
     * @Description queryDetail 查询详情
     * @param id
     */
    @RequestMapping(value = "/queryDetail", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<ReviewAnnounceVO> queryDetail(Long id) {
    	ReviewAnnounceEntity entity = service.selectById(id);
    	ReviewAnnounceVO vo = BeanMapper.map(entity, ReviewAnnounceVO.class);
        LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
        lambda.eq(ReviewAnnounceSupplierEntity::getPid, entity.getId());
        List<ReviewAnnounceSupplierEntity> supplierEntityList = reviewAnnounceSupplierService.list(lambda);
        Map<Long,List<ReviewAnnounceSupplierEntity>> map = supplierEntityList .stream().collect(Collectors.groupingBy(ReviewAnnounceSupplierEntity::getConfirmId));
        List<ReviewAnnounceConfirmVO> detailEntityList = vo.getReviewAnnounceConfirmList();
        if (CollectionUtils.isNotEmpty(detailEntityList)) {
            for(ReviewAnnounceConfirmVO confirmVO:detailEntityList){
                confirmVO.setSupplierList(BeanMapper.mapList(map.get(confirmVO.getId()),ReviewAnnounceSupplierVO.class));
            }
            vo.setReviewAnnounceConfirmList(TreeNodeBUtil.buildTree(detailEntityList));
        }
        return CommonResponse.success("查询详情数据成功！",vo);
    }

    /**
     * @Description delete 批量删除单据
     * @Param [ids]
     */
    @RequestMapping(value = "/delete", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<String> delete(@RequestBody List<ReviewAnnounceVO> vos) {
        if(ListUtil.isNotEmpty(vos)){
            for (ReviewAnnounceVO vo : vos) {
                LambdaQueryWrapper<ReviewAnnounceSupplierEntity> lambda = Wrappers.<ReviewAnnounceSupplierEntity>lambdaQuery();
                lambda.eq(ReviewAnnounceSupplierEntity::getPid, vo.getId());
                reviewAnnounceSupplierService.remove(lambda);
                ReviewAnnounceEntity entity =service.selectById(vo.getId());
                if (entity.getPurchaseProjectId() != null) {
                    LambdaUpdateWrapper<PurchaseProjectEntity> updateWrapper = Wrappers.lambdaUpdate();
                    updateWrapper.eq(PurchaseProjectEntity::getId, entity.getPurchaseProjectId());
                    updateWrapper.set(PurchaseProjectEntity::getDirectFlag, 0);
                    purchaseProjectService.update(updateWrapper);
                }
            }
        }
        service.removeByIds(vos.stream().map(ReviewAnnounceVO::getId).collect(Collectors.toList()),true);
        return CommonResponse.success("删除成功！");
    }

    /**
     * @Description queryList 查询列表
     * @param param
     * @Return com.ejianc.framework.core.response.CommonResponse<java.lang.String>
     */
    @RequestMapping(value = "/queryList", method = RequestMethod.POST)
    @ResponseBody
    public CommonResponse<IPage<ReviewAnnounceVO>> queryList(@RequestBody QueryParam param) {

        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "name", "orgName", "executePlanCode"));
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));

        /** 数据隔离 本下 没有组织orgId的删除下面代码-------------开始 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        /** 数据隔离 本下 没有组织orgId的删除上面代码-------------结束！！！ */

        IPage<ReviewAnnounceEntity> page = service.queryPage(param,false);
        IPage<ReviewAnnounceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
  		pageData.setRecords(BeanMapper.mapList(page.getRecords(), ReviewAnnounceVO.class));

        return CommonResponse.success("查询列表数据成功！",pageData);
    }

    /**
     * 获取RPC数据
     * resp 返回值
     * isMustSuc 是否必须成功
     * errMsg 失败提示
     */
    private Object getRespData(CommonResponse<?> resp, boolean isMustSuc, String errMsg) {
        if(isMustSuc && !resp.isSuccess()) {
            throw new BusinessException(StringUtils.isNoneBlank(errMsg) ? errMsg : "调用Rpc服务失败");
        }
        return resp.getData();
    }


    /**
     * @Description 导出
     * @param param
     * @Return void
     */
    @RequestMapping(value = "/excelExport", method = RequestMethod.POST)
    @ResponseBody
    public void excelExport(@RequestBody QueryParam param, HttpServletResponse response) {
        /** 模糊搜索配置字段示例 */
        List<String> fuzzyFields = param.getFuzzyFields();
        fuzzyFields.addAll(Arrays.asList("billCode", "name", "orgName", "executePlanCode"));
        param.getParams().put("tenant_id",new Parameter(QueryParam.EQ,InvocationInfoProxy.getTenantid()));
        param.setPageIndex(1);
        param.setPageSize(-1);
        /** 数据隔离 本下 没有组织orgId的删除下面代码 */
        param.getParams().put("orgId",new Parameter(QueryParam.IN,iOrgApi.findChildrenByParentId(InvocationInfoProxy.getOrgId()).getData().stream().map(OrgVO::getId).collect(Collectors.toList())));
        List<ReviewAnnounceEntity> list = service.queryList(param);
        List<ReviewAnnounceVO> voList = BeanMapper.mapList(list, ReviewAnnounceVO.class);
        for (ReviewAnnounceVO vo : voList) {
            Integer permissionType = vo.getPermissionType();
            if (permissionType != null) {
                if (permissionType.intValue() == 1) {
                    vo.setPermissionTypeName("一级集采");
                } else if (permissionType.intValue() == 2) {
                    vo.setPermissionTypeName("二级集采");
                } else if (permissionType.intValue() == 3) {
                    vo.setPermissionTypeName("所属单位");
                } else if (permissionType.intValue() == 4) {
                    vo.setPermissionTypeName("项目经理部");
                }
            }
            String businessType = vo.getBusinessType();
            if ("1".equals(businessType)) {
                vo.setBusinessTypeName("工程");
            } else if ("2".equals(businessType)) {
                vo.setBusinessTypeName("货物");
            }else {
                vo.setBusinessTypeName("服务");
            }
        }
        //todo:字段翻译等等
        Map<String, Object> beans = new HashMap<>();
        beans.put("records", voList);
        ExcelExport.getInstance().export("ReviewAnnounce-export.xlsx", beans, response);
    }

    /**
     * @Description 参照
     * @param
     * @Return void
     */
    @RequestMapping(value = "/refReviewAnnounceData", method = RequestMethod.GET)
    @ResponseBody
    public CommonResponse<IPage<ReviewAnnounceVO>> refReviewAnnounceData(@RequestParam Integer pageNumber, @RequestParam Integer pageSize,
                                                                        String condition,
                                                                        String searchObject,
                                                                        String searchText) {
        QueryParam param = new QueryParam();
        param.setPageSize(pageSize);
        param.setPageIndex(pageNumber);
        param.setSearchText(searchText);
        param.setSearchObject(searchObject);
        /** 租户隔离 */
        param.getParams().put("tenantId", new Parameter(QueryParam.EQ, InvocationInfoProxy.getTenantid()));
        if(StringUtils.isNotEmpty(condition)){
            /** 处理condition */
            JSONObject _con = JSONObject.parseObject(condition);
        }

        IPage<ReviewAnnounceEntity> page = service.queryPage(param,false);
        IPage<ReviewAnnounceVO> pageData = new Page<>(page.getCurrent(), page.getSize(), page.getTotal());
        pageData.setRecords(BeanMapper.mapList(page.getRecords(), ReviewAnnounceVO.class));

        return CommonResponse.success("查询参照数据成功！",pageData);
     }
}
